#include <bits/stdc++.h>

using namespace std;

/**
    Problem        : Chimichangas
    Algorithm      : polynomial multiplication using FFT (fast iterative implementation)
    Expected score : 100p
    Author         : Alexandru Valeanu
**/

const int MOD = 2999;

template <typename dataType>
class Complex
{
public:

    dataType re, im;

    Complex() : re(0), im(0) {
    }

    Complex (const dataType& a, const dataType& b) : re(a), im(b) {
    }

    Complex(const complex<dataType>& c) : re(c.real()), im(c.imag()) {
    }

    Complex& operator = (const complex<dataType>& c)
    {
        this->re = c.real();
        this->im = c.imag();

        return *this;
    }

    dataType real() const
    {
        return this->re;
    }

    dataType imag() const
    {
        return this->im;
    }

    void polar(const dataType& rho, const dataType& theta = 0)
    {
        this->re = rho * cos(theta);
        this->im = rho * sin(theta);
    }

    Complex conj() const
    {
        return Complex(this->re, -this->im);
    }

    dataType norm() const
    {
        return sqrt(this->re * this->re + this->im * this->im);
    }

    dataType normSquared() const
    {
        return this->re * this->re + this->im * this->im;
    }

    Complex inverse() const
    {
        return this->conj() / this->normSquared();
    }

    ///BEGIN OPERATORS-------------------------------------------------------------
    Complex operator + (const Complex<dataType>& c) const
    {
        return Complex(this->re + c.re, this->im + c.im);
    }

    Complex& operator += (const Complex<dataType>& c)
    {
        *this = *this + c;
        return *this;
    }

    Complex operator - (const Complex<dataType>& c) const
    {
        return Complex(this->re - c.re, this->im - c.im);
    }

    Complex& operator -= (const Complex<dataType>& c)
    {
        *this = *this + c;
        return *this;
    }

    Complex operator * (const Complex<dataType>& c) const
    {
        double aux_re = this->re * c.real() - this->im * c.imag();
        double aux_im = this->re * c.imag() + this->im * c.real();

        return Complex(aux_re, aux_im);
    }

    Complex& operator *= (const Complex<dataType>& c)
    {
        *this = *this * c;
        return *this;
    }

    Complex operator * (const dataType& c) const
    {
        return Complex(this->re * c, this->im * c);
    }

    Complex& operator *= (const dataType& c)
    {
        *this = *this * c;
        return *this;
    }

    Complex operator / (const Complex<dataType>& c) const
    {
        return *this * c.inverse();
    }

    Complex& operator /= (const Complex<dataType>& c)
    {
        *this = *this / c;
        return *this;
    }

    Complex operator / (const dataType& c) const
    {
        return Complex(this->re / c, this->im / c);
    }

    Complex& operator /= (const dataType& c)
    {
        *this = *this / c;
        return *this;
    }
    ///END OPERATORS--------------------------------------------------------------------

    friend istream& operator >> (istream& stream, Complex& C)
    {
        stream >> C.re >> C.im;
        return stream;
    }

    friend ostream& operator << (ostream& stream, const Complex& C)
    {
        stream << C.re << " " << C.im;
        return stream;
    }
};

namespace FFT
{
    int N, EXP;

    int reverse_bits(int x)
    {
        int rev_x = 0;

        for (int i = 0; i < EXP; ++i)
        {
            bool bit = x & (1 << i);

            rev_x <<= 1;
            rev_x |= bit;
        }

        return rev_x;
    }

    void fft(vector<Complex<double>> &A, int inverse)
    {
        for (int i = 0; i < N; ++i)
        {
            int j = reverse_bits(i);

            if (i < j)
                swap(A[i], A[j]);
        }

        for (int length = 2; length <= N; length *= 2)
        {
            Complex<double> root = polar(1.0, 2.0 * M_PI * (1.0 * inverse) / length);

            for (int start = 0; start < N; start += length)
            {
                Complex<double> wk(1.0);

                for (int i = 0; i < length / 2; ++i)
                {
                    Complex<double> u = A[start + i];
                    Complex<double> v = A[start + i + length / 2] * wk;

                    A[start + i]              = u + v;
                    A[start + i + length / 2] = u - v;

                    wk *= root;
                }
            }
        }

        if (inverse == -1)
        {
            for (int i = 0; i < N; ++i)
                A[i] /= (1.0 * N);
        }
    }

    void convolution(vector<Complex<double>> &A, vector<Complex<double>> &B, vector<Complex<double>> &C)
    {
        fft(A, 1);
        fft(B, 1);

        for (int i = 0; i < N; ++i)
            C[i] = A[i] * B[i];

        fft(C, -1);
    }

    void computeLimits(int n, int m)
    {
        EXP = 0;

        while ((1 << EXP) < n + m)
            EXP++;

        N = (1 << EXP);
    }
}

template <typename dataType>
class Polynomial
{
public:

    vector<dataType> a;
    int degree; /// = a.size() + 1

    explicit Polynomial() : a(vector<dataType>()), degree(0) {
    }

    Polynomial(const int D) : a(vector<dataType>(D + 1, 0)), degree(D) {
    }

    Polynomial& operator = (const Polynomial &P)
    {
        this->a.clear();
        this->degree = 0;

        this->a = P.a;
        this->degree = P.degree;

        return *this;
    }

    void resize(const int D)
    {
        this->a.clear();
        this->degree = 0;

        this->a = vector<dataType>(D + 1, 0);
        this->degree = D;
    }

    dataType& operator [] (const int p)
    {
        return this->a[p];
    }

    dataType operator [] (const int p) const
    {
        return this->a[p];
    }

    Polynomial& operator *= (const Polynomial &P)
    {
        ///brute-force CUT-OFF ------------------------------------------------
        if (1LL * this->degree * P.degree < 500 * 500LL)
        {
            Polynomial solution(this->degree + P.degree);

            for (int i = 0; i <= this->degree; ++i)
                for (int j = 0; j <= P.degree; ++j)
                {
                    int s = (this->a[i] * P[j]) % MOD;
                    solution[i + j] = (solution[i + j] + s) % MOD;
                }

            *this = solution;

            return *this;
        }
        /// -------------------------------------------------------------------

        vector<Complex<double>> A, B, C;

        FFT::computeLimits(this->degree + 1, P.degree + 1);

        A.resize(FFT::N);
        B.resize(FFT::N);
        C.resize(FFT::N);

        for (int i = 0; i <= this->degree; ++i)
            A[i] = Complex<double>(this->a[i], 0);

        for (int i = 0; i <= P.degree; ++i)
            B[i] = Complex<double>(P[i], 0);

        for (int i = this->degree + 1; i < FFT::N; ++i)
            A[i] = 0;

        for (int i = P.degree + 1; i < FFT::N; ++i)
            B[i] = 0;

        FFT::convolution(A, B, C);

        Polynomial solution(this->degree + P.degree);

        for (int i = 0; i <= solution.degree; ++i)
        {
            long long val = std::round(C[i].real());

            solution[i] = val % MOD;
        }

        *this = solution;

        return *this;
    }

    void power(int exponent)
    {
        assert(exponent > 0);
        exponent--;

        Polynomial solution = *this;
        Polynomial A = *this;

        while (exponent > 0)
        {
            if (exponent & 1)
                solution *= A;

            A *= A;
            exponent >>= 1;
        }

        *this = solution;
    }

    friend ostream& operator << (ostream& stream, const Polynomial &P)
    {
        for (int i = P.degree; i >= 0; i--)
        {
            stream << P[i];

            if (i > 0)
                stream << ' ';
        }

        return stream;
    }
};

int main()
{
    ifstream in("chimichangas.in");
    ofstream out("chimichangas.out");

    int N, K;
    int Q;

    assert(in >> N >> K);

    int maxC = 0;
    vector<int> calory;

    for (int i = 0; i < N; ++i)
    {
        int x;
        assert(in >> x);

        calory.push_back(x);
    }

    maxC = *max_element(calory.begin(), calory.end());

    Polynomial<int> P(maxC);

    for (int i = 0; i < N; ++i)
        P[ calory[i] ] = 1;

    P.power(K);
    assert(P.degree == maxC * K);

    assert(in >> Q);

    while (Q--)
    {
        int weight;
        assert(in >> weight);

        if (weight > maxC * K)
            out << 0 << "\n";
        else
            out << P[weight] << "\n";
    }

    return 0;
}
