#include <bits/stdc++.h>

using namespace std;

/**
    Problem        : Chimichangas
    Algorithm      : polynomial multiplication using Karatsuba in O(n ^ log2(3))
    Expected score : 70p
    Author         : Alexandru Valeanu
**/

const int MOD = 2999;

void addMod(short &a, short b)
{
    a += b;

    if (a >= MOD)
        a -= MOD;
}

void subtractMod(short &a, short b)
{
    a -= b;

    if (a < 0)
        a += MOD;
}

vector<short> karatsubaMultiplication(const vector<short> &A, const vector<short> &B)
{
    const size_t N = A.size();
    vector<short> solution(2 * N, 0);

    if (N <= 16)
    {
        for (size_t i = 0; i < N; ++i)
            for (size_t j = 0; j < N; ++j)
            {
                short s = (A[i] * B[j]) % MOD;
                addMod(solution[i + j], s);
            }

        return solution;
    }

    size_t p = N / 2;

    vector<short> a1(A.begin(), A.begin() + p);
    vector<short> a2(A.begin() + p, A.end());
    vector<short> b1(B.begin(), B.begin() + p);
    vector<short> b2(B.begin() + p, B.end());

    vector<short> a1b1 = karatsubaMultiplication(a1, b1);
    vector<short> a2b2 = karatsubaMultiplication(a2, b2);

    for (size_t i = 0; i < p; ++i)
    {
        addMod(a2[i], a1[i]);
        addMod(b2[i], b1[i]);
    }

    vector<short> tmp = karatsubaMultiplication(a2, b2);

    for (size_t i = 0; i < N; ++i)
    {
        subtractMod(tmp[i], a1b1[i]);
        subtractMod(tmp[i], a2b2[i]);

        addMod(solution[i + p], tmp[i]);
        addMod(solution[i], a1b1[i]);
        addMod(solution[i + N], a2b2[i]);
    }

    return solution;
}

template <typename dataType>
class Polynomial
{
public:

    vector<dataType> a;
    int degree; /// = a.size() + 1

    explicit Polynomial() : a(vector<dataType>()), degree(0) {
    }

    Polynomial(const int D) : a(vector<dataType>(D + 1, 0)), degree(D) {
    }

    Polynomial& operator = (const Polynomial &P)
    {
        this->a.clear();
        this->degree = 0;

        this->a = P.a;
        this->degree = P.degree;

        return *this;
    }

    void resize(const int D)
    {
        this->a.clear();
        this->degree = 0;

        this->a = vector<dataType>(D + 1, 0);
        this->degree = D;
    }

    dataType& operator [] (const int p)
    {
        return this->a[p];
    }

    dataType operator [] (const int p) const
    {
        return this->a[p];
    }

    Polynomial& operator *= (const Polynomial &P)
    {
        const int L = max(this->degree + 1, P.degree + 1);

        int pw = 1;

        while (pw < L)
            pw <<= 1;

        vector<short> A(pw, 0);
        vector<short> B(pw, 0);

        for (int i = 0; i <= this->degree; ++i)
            A[i] = this->a[i];

        for (int i = 0; i <= P.degree; ++i)
            B[i] = P[i];

        Polynomial solution(this->degree + P.degree);

        vector<short> C = karatsubaMultiplication(A, B);

        for (int i = 0; i <= solution.degree; ++i)
            solution[i] = C[i];

        *this = solution;

        return *this;
    }

    void power(int exponent)
    {
        assert(exponent > 0);
        exponent--;

        Polynomial solution = *this;
        Polynomial A = *this;

        while (exponent > 0)
        {
            if (exponent & 1)
                solution *= A;

            A *= A;
            exponent >>= 1;
        }

        *this = solution;
    }

    friend ostream& operator << (ostream& stream, const Polynomial &P)
    {
        for (int i = P.degree; i >= 0; i--)
        {
            stream << P[i];

            if (i > 0)
                stream << ' ';
        }

        return stream;
    }
};

int main()
{
    ifstream in("chimichangas.in");
    ofstream out("chimichangas.out");

    int N, K;
    int Q;

    assert(in >> N >> K);

    int maxC = 0;
    vector<int> calory;

    for (int i = 0; i < N; ++i)
    {
        int x;
        assert(in >> x);

        calory.push_back(x);
    }
    
    in >> Q;

    if (K == 2 && Q <= 100)
    {
        set<int> seen;

        for (int i = 0; i < N; ++i)
            seen.insert(calory[i]);

        while (Q--)
        {
            int weight;
            in >> weight;

            int sol = 0;

            for (int i = 0; i < N; ++i)
            {
                if (seen.find(weight - calory[i]) != seen.end())
                    sol++;
            }

            out << sol % MOD << "\n";
        }

        return 0;
    }

    maxC = *max_element(calory.begin(), calory.end());

    Polynomial<int> P(maxC);

    for (int i = 0; i < N; ++i)
        P[ calory[i] ] = 1;

    P.power(K);
    assert(P.degree == maxC * K);

    while (Q--)
    {
        int weight;
        assert(in >> weight);

        if (weight > maxC * K)
            out << 0 << "\n";
        else
            out << P[weight] << "\n";
    }

    return 0;
}


