/**
 * Method: compute A^k = (x^calorie_1 + ... + x^calorie_n)^k with the Karatsuba method.
 * The answer for a target of meal_i is the coefficient of x^meal_i in A^k.
 **/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define MAX_DEGREE 100000
#define MAX_LEVELS 18 /* 2^0 through 2^17 */
#define MODULO 2999
#define THRESHOLD 64
#define MAX(x, y) (((x) > (y)) ? (x) : (y))
#define MIN(x, y) (((x) < (y)) ? (x) : (y))

typedef struct {
  int d;    /* degree */
  short *c; /* c[i] is the coefficient of x^i */
} poly;

/* Auxiliary variables for the recursive Karatsuba algorithm, 4 per level. */
poly w[MAX_LEVELS][4];

/* Buffer for the naive multiplication */
unsigned buf[2 * THRESHOLD + 1];

/* Allocates a polynomial of degree at most d */
void allocPoly(poly *p, int d) {
  p->c = (short*)calloc(d + 1, sizeof(short));
}

/* A += B */
void sum(poly *a, poly *b) {
  int i;

  /* Make sure deg(A) >= deg(B) */
  if (b->d > a->d) {
    for (i = a->d + 1; i <= b->d; i++) {
      a->c[i] = 0;
    }
    a->d = b->d;
  }
  for (i = 0; i <= b->d; i++) {
    a->c[i] += b->c[i];
    a->c[i] -= MODULO * (a->c[i] >= MODULO);
  }
}

/* A -= B. Assumes that deg(A) >= deg(B). */
void diff(poly *a, poly *b) {
  int i;

  for (i = 0; i <= b->d; i++) {
    a->c[i] += MODULO - b->c[i];
    a->c[i] -= MODULO * (a->c[i] >= MODULO);
  }
}

/* Copy coefficients [from...to] from src to dest */
void copy(poly *dest, poly *src, int from, int to) {
  int i;

  dest->d = to - from;
  for (i = 0; i <= dest->d; i++) {
    dest->c[i] = src->c[from + i];
  }
}

/* A *= x^k */
void shift(poly *a, int k) {
  int i;

  for (i = a->d; i >= 0; i--) {
    a->c[i + k] = a->c[i];
  }
  for (i = 0; i < k; i++) {
    a->c[i] = 0;
  }
  a->d += k;
}

/* C = A * B. Naive version. */
void multNaive(poly *a, poly *b, poly *c) {
  int i, j;

  memset(buf, 0, sizeof(buf));
  c->d = a->d + b->d;

  for (i = 0; i <= a->d; i++) {
    for (j = 0; j <= b->d; j++) {
      buf[i + j] += a->c[i] * b->c[j];
    }
  }

  for (i = 0; i <= c->d; i++) {
    c->c[i] = buf[i] % MODULO;
  }
}

/* C = A * B. Writes A = XY and B = ZT and applies Karatsuba's algorithm. */
/* Assumes that deg(A) >= deg(B). */
void mult(poly *a, poly *b, poly *c, int l) {
  if (a->d <= THRESHOLD) {
    multNaive(a, b, c);
    return;
  }

  poly *p = &w[l][0], *q = &w[l][1], *r = &w[l][2], *s = &w[l][3];
  int n = a->d / 2;            /* the degree of y */
  int bcut = MIN(n, b->d);     /* because possibly deg(B) < n */
  copy(p, a, n + 1, a->d);     /* p = X */
  copy(q, a, 0, n);            /* q = Y */
  copy(r, b, bcut + 1, b->d);  /* r = Z */
  copy(s, b, 0, bcut);         /* s = T */
  mult(p, r, c, l + 1);        /* c = XZ */
  sum(p, q);                   /* p = X + Y */
  sum(r, s);                   /* r = Z + T */
  mult(p, r, s, l + 1);        /* s = (X + Y)(Z + T) */
  copy(r, b, 0, bcut);         /* r = T */
  mult(q, r, p, l + 1);        /* p = YT */
  diff(s, c);
  diff(s, p);                  /* s = XT + YZ */
  shift(c, n + 1);             /* c = XZ * x^n */
  sum(c, s);                   /* c = XZ * x^n + (XT + YZ) */
  shift(c, n + 1);             /* c = XZ * x^(2n) + (XT + YZ) * x^n */
  sum(c, p);                   /* c = XZ * x^(2n) + (XT + YZ) * x^n + YT */

  while ((c->d > a->d + b->d) && !c->c[c->d]) {
    c->d--;
  }
}

int main(void) {
  int n, k, x, q, i, j;
  poly p, z, tmp;

  /* Allocate memory for polynomials. Since the polynomials are smaller */
  /* at higher recursion levels, we need less memory. */
  allocPoly(&p, MAX_DEGREE);
  allocPoly(&z, MAX_DEGREE);
  allocPoly(&tmp, MAX_DEGREE);
  for (i = 0; i < MAX_LEVELS; i++) {
    for (j = 0; j < 4; j++) {
      allocPoly(&w[i][j], 1 << (MAX_LEVELS - i));
    }
  }

  FILE *fin = fopen("chimichangas.in", "r");
  FILE *fout = fopen("chimichangas.out", "w");
  fscanf(fin, "%d%d", &n, &k);

  /* Construct P = A^1 */
  p.d = 0;
  while (n--) {
    fscanf(fin, "%d", &x);
    p.c[x] = 1;
    p.d = MAX(p.d, x);
  }

  /* P iterates through A^(2^i). */
  /* Z collects the powers we need for A^k. */
  z.d = 0;
  z.c[0] = 1;
  while (k) {
    if (k & 1) {
      mult(&p, &z, &tmp, 0);
      copy(&z, &tmp, 0, tmp.d);
    }
    k >>= 1;
    if (k) {
      mult(&p, &p, &tmp, 0);
      copy(&p, &tmp, 0, tmp.d);
    }
  }

  /* Answer the queries. */
  fscanf(fin, "%d", &q);
  while (q--) {
    fscanf(fin, "%d", &x);
    fprintf(fout, "%d\n", (x > z.d) ? 0 : z.c[x]);
  }

  fclose(fin);
  fclose(fout);

  return 0;
}
